==> e107-0.7.20.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/forum/languages/English/lan_forum.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("e_PAGETITLE", "Forum");
	
define("LAN_30", "Welcome");
define("LAN_31", "There are no new posts ");
define("LAN_32", "There is 1 new post ");
define("LAN_33", "There are");
define("LAN_34", "new posts");
define("LAN_35", "since your last visit.");
define("LAN_36", "You last visited at ");
define("LAN_37", "It is now ");
define("LAN_38", ", all times are ");
define("LAN_41", "Newest member: ");
define("LAN_42", "Registered members: ");
define("LAN_44", "These forums can be used by non-registered users, but please be aware that your IP Address will be logged if you make a post.<br />To access the full features of this forum you will need to");
define("LAN_45", "These forums can only be posted to by registered and logged in members, please click");
define("LAN_46", "Forum");
define("LAN_47", "Threads");
define("LAN_48", "Replies");
define("LAN_49", "Last Post");
define("LAN_51", "No forums yet, please check back soon.");
define("LAN_52", "No forums in this section yet, please check back soon.");
define("LAN_79", "New posts");
define("LAN_80", " No new posts");
define("LAN_81", "Closed thread");
define("LAN_100", "articles");
define("LAN_180", "Search");
define("LAN_191", "Information");
define("LAN_192", "The users of this forum have made a total of ");
define("LAN_196", "You have read ");
define("LAN_197", " of these posts.");
define("LAN_198", " All new posts have been read.");
define("LAN_199", "Mark all posts as read");
define("LAN_204", "You <b>can</b> start new threads");
define("LAN_205", "You <b>cannot</b> start new threads");
define("LAN_206", "You <b>can</b> post replies");
define("LAN_207", "You <b>cannot</b> post replies");
define("LAN_208", "You <b>can</b> edit your posts");
define("LAN_209", "You <b>cannot</b> edit your posts");
define("LAN_392", "stop tracking this thread");
define("LAN_393", "List tracked threads");
define("LAN_394", "Closed forum");
define("LAN_397", "Tracked threads");
define("LAN_398", "Closed");
define("LAN_399", "Restricted");
define("LAN_400", "This forum can only be browsed by registered members");
define("LAN_401", "Members only");
	
define("LAN_402", "This forum is read only");
	
define("LAN_403", "No posts yet");
define("LAN_404", "posts");
define("LAN_405", "Restricted Access");
	
define("LAN_406", "This forum is restricted to administrators only");
define("LAN_407", "This forum is restricted to members only");
define("LAN_408", "This is a read-only forum");
define("LAN_409", "This is a class restricted forum");
define("LAN_410", "Welcome guest");
	
define("LAN_411", "thread");
define("LAN_412", "reply");
define("LAN_413", "threads");
define("LAN_414", "replies");
define("LAN_415", "user is browsing the forums at the moment");
define("LAN_416", "users are browsing the forums at the moment");
	
define("LAN_417", "member");
define("LAN_418", "guest");
define("LAN_419", "members");
define("LAN_420", "guests");
	
define("LAN_421", "Show new posts");
define("LAN_422", "New posts since your last visit");
define("LAN_423", "Posted by");
define("LAN_424", "New threads");
define("LAN_425", "Re:");
	
//v.616
define("LAN_426", "Who's Online: ");
define("LAN_427", "View detailed list.");
define("LAN_428", "Re:");
define("LAN_429", "Top Posters");
define("LAN_430", "Most Active Threads");
define("LAN_431", "My Posts");
define("LAN_432", "My Settings");
define("LAN_433", "Forum Rules");
define("LAN_434", "Return to forums");
define("LAN_435", "My Profile");
define("LAN_436", " (Will open a new window.)");
	
define("LAN_437", "register");
define("LAN_438", "and login.");
define("LAN_439", "here");
define("LAN_440", "to go to the registration page.");

define("LAN_441", "View forum statistics");
	
define('FORLAN_441', 'No rules defined.');
define('FORLAN_442', 'My Uploads');
define('FORLAN_443', '[user deleted]');
define('FORLAN_444', 'sub-forums');

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/forum/languages/English/lan_forum.php $
|     $Revision: 11678 $
|     $Id: lan_forum.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("e_PAGETITLE", "Forum");
	
define("LAN_30", "Welcome");
define("LAN_31", "There are no new posts ");
define("LAN_32", "There is 1 new post ");
define("LAN_33", "There are");
define("LAN_34", "new posts");
define("LAN_35", "since your last visit.");
define("LAN_36", "You last visited at ");
define("LAN_37", "It is now ");
define("LAN_38", ", all times are ");
define("LAN_41", "Newest member: ");
define("LAN_42", "Registered members: ");
define("LAN_44", "These forums can be used by non-registered users, but please be aware that your IP Address will be logged if you make a post.<br />To access the full features of this forum you will need to");
define("LAN_45", "These forums can only be posted to by registered and logged in members, please click");
define("LAN_46", "Forum");
define("LAN_47", "Threads");
define("LAN_48", "Replies");
define("LAN_49", "Last Post");
define("LAN_51", "No forums yet, please check back soon.");
define("LAN_52", "No forums in this section yet, please check back soon.");
define("LAN_79", "New posts");
define("LAN_80", " No new posts");
define("LAN_81", "Closed thread");
define("LAN_100", "articles");
define("LAN_180", "Search");
define("LAN_191", "Information");
define("LAN_192", "The users of this forum have made a total of ");
define("LAN_196", "You have read ");
define("LAN_197", " of these posts.");
define("LAN_198", " All new posts have been read.");
define("LAN_199", "Mark all posts as read");
define("LAN_204", "You <b>can</b> start new threads");
define("LAN_205", "You <b>cannot</b> start new threads");
define("LAN_206", "You <b>can</b> post replies");
define("LAN_207", "You <b>cannot</b> post replies");
define("LAN_208", "You <b>can</b> edit your posts");
define("LAN_209", "You <b>cannot</b> edit your posts");
define("LAN_392", "stop tracking this thread");
define("LAN_393", "List tracked threads");
define("LAN_394", "Closed forum");
define("LAN_397", "Tracked threads");
define("LAN_398", "Closed");
define("LAN_399", "Restricted");
define("LAN_400", "This forum can only be browsed by registered members");
define("LAN_401", "Members only");
	
define("LAN_402", "This forum is read only");
	
define("LAN_403", "No posts yet");
define("LAN_404", "posts");
define("LAN_405", "Restricted Access");
	
define("LAN_406", "This forum is restricted to administrators only");
define("LAN_407", "This forum is restricted to members only");
define("LAN_408", "This is a read-only forum");
define("LAN_409", "This is a class restricted forum");
define("LAN_410", "Welcome guest");
	
define("LAN_411", "thread");
define("LAN_412", "reply");
define("LAN_413", "threads");
define("LAN_414", "replies");
define("LAN_415", "user is browsing the forums at the moment");
define("LAN_416", "users are browsing the forums at the moment");
	
define("LAN_417", "member");
define("LAN_418", "guest");
define("LAN_419", "members");
define("LAN_420", "guests");
	
define("LAN_421", "Show new posts");
define("LAN_422", "New posts since your last visit");
define("LAN_423", "Posted by");
define("LAN_424", "New threads");
define("LAN_425", "Re:");
	
//v.616
define("LAN_426", "Who's Online: ");
define("LAN_427", "View detailed list.");
define("LAN_428", "Re:");
define("LAN_429", "Top Posters");
define("LAN_430", "Most Active Threads");
define("LAN_431", "My Posts");
define("LAN_432", "My Settings");
define("LAN_433", "Forum Rules");
define("LAN_434", "Return to forums");
define("LAN_435", "My Profile");
define("LAN_436", " (Will open a new window.)");
	
define("LAN_437", "register");
define("LAN_438", "and login.");
define("LAN_439", "here");
define("LAN_440", "to go to the registration page.");

define("LAN_441", "View forum statistics");
	
define('FORLAN_441', 'No rules defined.');
define('FORLAN_442', 'My Uploads');
define('FORLAN_443', '[user deleted]');
define('FORLAN_444', 'sub-forums');

?>
